@@ -2,7 +2,7 @@
 """
 from core_main_app.access_control.decorators import access_control
 from core_parser_app import access_control as parser_access_control
-from core_parser_app.components.data_structure_element.models import (
+from core_parser_app.components.data_structure.models import (
     DataStructureElement,
 )
 
@@ -18,29 +18,8 @@ def upsert(data_structure_element, request):
     Returns:
 
     """
-    return data_structure_element.save()
-
-
-@access_control(parser_access_control.is_data_structure_element_owner)
-def get_all_by_child_id(child_id, request):
-    """Get Data structure element object which contains the given child id in
-    its children
-
-    Args:
-        child_id:
-        request:
-
-    Returns:
-
-    """
-    if request.user.is_superuser:
-        return DataStructureElement.get_all_by_child_id(child_id)
-    elif request.user.is_anonymous:
-        return DataStructureElement.get_all_by_child_id_and_user(child_id, user=None)
-    else:
-        return DataStructureElement.get_all_by_child_id_and_user(
-            child_id, user=str(request.user.id)
-        )
+    data_structure_element.save()
+    return data_structure_element
 
 
 @access_control(parser_access_control.is_data_structure_element_owner)
@@ -55,31 +34,30 @@ def get_by_id(data_structure_element_id, request):
     """
     if request.user.is_superuser:
         return DataStructureElement.get_by_id(data_structure_element_id)
-    elif request.user.is_anonymous:
+    if request.user.is_anonymous:
         return DataStructureElement.get_by_id_and_user(
             data_structure_element_id, user=None
         )
-    else:
-        return DataStructureElement.get_by_id_and_user(
-            data_structure_element_id, user=str(request.user.id)
-        )
+    return DataStructureElement.get_by_id_and_user(
+        data_structure_element_id, user=str(request.user.id)
+    )
 
 
 @access_control(parser_access_control.is_data_structure_element_owner)
 def get_by_xpath(xpath, request):
     """List all DataStructureElement
     Args :
-        xpath
+        xpath:
+        request:
+
     Returns: DataStructureElement collection
     """
     if request.user.is_superuser:
         return DataStructureElement.get_by_xpath(xpath)
-    elif request.user.is_anonymous:
+    if request.user.is_anonymous:
         return DataStructureElement.get_by_xpath_and_user(xpath, user=None)
-    else:
-        return DataStructureElement.get_by_xpath_and_user(
-            xpath, user=str(request.user.id)
-        )
+
+    return DataStructureElement.get_by_xpath_and_user(xpath, user=str(request.user.id))
 
 
 @access_control(parser_access_control.is_data_structure_element_owner)
@@ -94,9 +72,7 @@ def remove_child(data_structure_element, child, request):
     Returns:
 
     """
-    data_structure_element.update(pull__children=child)
-    data_structure_element.reload()
-
+    data_structure_element.children.remove(child)
     return data_structure_element
 
 
@@ -112,9 +88,7 @@ def add_child(data_structure_element, child, request):
     Returns:
 
     """
-    data_structure_element.update(add_to_set__children=[child])
-    data_structure_element.reload()
-
+    data_structure_element.children.add(child)
     return data_structure_element
 
 
@@ -129,11 +103,4 @@ def get_root_element(data_structure_element, request):
     Returns:
 
     """
-    current_element = data_structure_element
-    parent_list = get_all_by_child_id(current_element.id, request)
-
-    while len(parent_list) > 0:  # Browse parents while there is still one
-        current_element = parent_list[0]
-        parent_list = get_all_by_child_id(current_element.id, request)
-
-    return current_element
+    return data_structure_element.data_structure.data_structure_element_root
