@@ -1,12 +1,12 @@
 """API for modules
 """
 from core_main_app.components.template import api as template_api
-from core_parser_app.components.module.models import Module
-from core_parser_app.settings import MODULE_TAG_NAME
 from xml_utils.xsd_tree.operations.appinfo import (
     add_appinfo_element,
     delete_appinfo_element,
 )
+from core_parser_app.components.module.models import Module
+from core_parser_app.settings import MODULE_TAG_NAME
 
 
 def get_by_id(module_id):
@@ -72,13 +72,14 @@ def delete_all():
     Module.delete_all()
 
 
-def add_module(template, module_id, xpath):
+def add_module(template, module_id, xpath, request):
     """Inserts a module in a template
 
     Args:
         template:
         module_id:
         xpath:
+        request:
 
     Returns:
 
@@ -89,15 +90,16 @@ def add_module(template, module_id, xpath):
     template.content = add_appinfo_element(
         template.content, xpath, MODULE_TAG_NAME, module_object.url
     )
-    return template_api.upsert(template)
+    return template_api.upsert(template, request=request)
 
 
-def delete_module(template, xpath):
+def delete_module(template, xpath, request):
     """Deletes a module from a template
 
     Args:
         template:
         xpath:
+        request:
 
     Returns:
 
@@ -105,4 +107,4 @@ def delete_module(template, xpath):
     # delete module attribute from element
     template.content = delete_appinfo_element(template.content, xpath, MODULE_TAG_NAME)
 
-    return template_api.upsert(template)
+    return template_api.upsert(template, request=request)
