@@ -3,19 +3,22 @@
 from os.path import join, dirname, abspath
 from unittest.case import TestCase
 
-from core_parser_app.tools.parser.parser import XSDParser
-from tests.test_utils import DataHandler
 from xml_utils.commons.constants import LXML_SCHEMA_NAMESPACE, SCHEMA_NAMESPACE
 from xml_utils.xsd_tree.xsd_tree import XSDTree
 
+from core_parser_app.tools.parser.parser import XSDParser
+from tests.test_utils import DataHandler
+
 # FIXME: use django finder
 RESOURCES_PATH = join(dirname(abspath(__file__)), "..", "data")
 
 
 class ParserCreateChoiceTestSuite(TestCase):
-    """"""
+    """Parser Create Choice Test Suite"""
 
     def setUp(self):
+        """setUp"""
+
         choice_data = join(RESOURCES_PATH, "parser", "choice")
         self.choice_data_handler = DataHandler(choice_data)
 
@@ -27,6 +30,8 @@ class ParserCreateChoiceTestSuite(TestCase):
         self.parser = XSDParser()
 
     def test_create_element_basic(self):
+        """test_create_element_basic"""
+
         xsd_files = join("element", "basic")
         xsd_tree = self.choice_data_handler.get_xsd(xsd_files)
         xsd_element = xsd_tree.xpath(
@@ -42,6 +47,8 @@ class ParserCreateChoiceTestSuite(TestCase):
         self.assertDictEqual(expected_element, result_string)
 
     def test_create_element_unbounded(self):
+        """test_create_element_unbounded"""
+
         xsd_files = join("element", "unbounded")
         xsd_tree = self.choice_data_handler.get_xsd(xsd_files)
         xsd_element = xsd_tree.xpath(
@@ -57,6 +64,8 @@ class ParserCreateChoiceTestSuite(TestCase):
         self.assertDictEqual(expected_element, result_string)
 
     def test_create_sequence_basic(self):
+        """test_create_sequence_basic"""
+
         xsd_files = join("sequence", "basic")
         xsd_tree = self.choice_data_handler.get_xsd(xsd_files)
         xsd_element = xsd_tree.xpath(
@@ -72,6 +81,8 @@ class ParserCreateChoiceTestSuite(TestCase):
         self.assertDictEqual(expected_element, result_string)
 
     def test_create_sequence_unbounded(self):
+        """test_create_sequence_unbounded"""
+
         xsd_files = join("sequence", "unbounded")
         xsd_tree = self.choice_data_handler.get_xsd(xsd_files)
         xsd_element = xsd_tree.xpath(
@@ -88,9 +99,11 @@ class ParserCreateChoiceTestSuite(TestCase):
 
 
 class ParserReloadChoiceTestSuite(TestCase):
-    """"""
+    """Parser Reload Choice Test Suite"""
 
     def setUp(self):
+        """setUp"""
+
         choice_data = join(RESOURCES_PATH, "parser", "choice")
         self.choice_data_handler = DataHandler(choice_data)
 
@@ -103,6 +116,8 @@ class ParserReloadChoiceTestSuite(TestCase):
         self.parser.editing = True
 
     def test_reload_element_basic(self):
+        """test_reload_element_basic"""
+
         xsd_files = join("element", "basic")
         xsd_tree = self.choice_data_handler.get_xsd(xsd_files)
         xsd_element = xsd_tree.xpath(
@@ -122,6 +137,8 @@ class ParserReloadChoiceTestSuite(TestCase):
         self.assertDictEqual(expected_element, result_string)
 
     def test_reload_element_unbounded(self):
+        """test_reload_element_unbounded"""
+
         xsd_files = join("element", "unbounded")
         xsd_tree = self.choice_data_handler.get_xsd(xsd_files)
         xsd_element = xsd_tree.xpath(
@@ -141,6 +158,8 @@ class ParserReloadChoiceTestSuite(TestCase):
         self.assertDictEqual(expected_element, result_string)
 
     def test_reload_sequence_basic(self):
+        """test_reload_sequence_basic"""
+
         xsd_files = join("sequence", "basic")
         xsd_tree = self.choice_data_handler.get_xsd(xsd_files)
         xsd_element = xsd_tree.xpath(
@@ -160,6 +179,8 @@ class ParserReloadChoiceTestSuite(TestCase):
         self.assertDictEqual(expected_element, result_string)
 
     def test_reload_sequence_unbounded(self):
+        """test_reload_sequence_unbounded"""
+
         xsd_files = join("sequence", "unbounded")
         xsd_tree = self.choice_data_handler.get_xsd(xsd_files)
         xsd_element = xsd_tree.xpath(
